@@ -49,7 +49,7 @@ function mc_issue_get( $p_username, $p_password, $p_issue_id ) {
 	if( $t_user_id === false ) {
 		return mci_soap_fault_login_failed();
 	}
-	
+
 	$t_lang = mci_get_user_lang( $t_user_id );
 
 	if( !bug_exists( $p_issue_id ) ) {
@@ -62,7 +62,7 @@ function mc_issue_get( $p_username, $p_password, $p_issue_id ) {
 	}
 
 	if( !access_has_bug_level( VIEWER, $p_issue_id, $t_user_id ) ){
-	    return mci_soap_fault_access_denied( $t_user_id );
+		return mci_soap_fault_access_denied( $t_user_id );
 	}
 
 	$t_bug = bug_get( $p_issue_id, true );
@@ -114,25 +114,25 @@ function mc_issue_get( $p_username, $p_password, $p_issue_id ) {
 	$t_issue_data['custom_fields'] = mci_issue_get_custom_fields( $p_issue_id );
 	$t_issue_data['monitors'] = mci_account_get_array_by_ids( bug_get_monitors ( $p_issue_id ) );
 	$t_issue_data['tags'] = mci_issue_get_tags_for_bug_id( $p_issue_id , $t_user_id );
-	
+
 	return $t_issue_data;
 }
 
 /**
  * Returns the category name, possibly null if no category is assigned
- * 
+ *
  * @param int $p_category_id
- * @return string 
+ * @return string
  */
 function mci_get_category( $p_category_id ) {
 	if ( $p_category_id == 0 )
 		return '';
-		
+
 	return mci_null_if_empty( category_get_name( $p_category_id ) );
 }
 
 /**
- * 
+ *
  * @param BugData $bug
  * @return soapval the value to be encoded as the due date
  */
@@ -142,7 +142,7 @@ function mci_issue_get_due_date( $p_bug ) {
 	} else {
 		return new soapval( 'due_date','xsd:dateTime', null );
 	}
-	
+
 }
 
 /**
@@ -234,11 +234,11 @@ function mci_issue_get_custom_fields( $p_issue_id ) {
  */
 function mci_issue_get_attachments( $p_issue_id ) {
 	$t_attachment_rows = bug_get_attachments( $p_issue_id );
-	
+
 	if ( $t_attachment_rows == null) {
 		return array();
 	}
-	
+
 	$t_result = array();
 	foreach( $t_attachment_rows as $t_attachment_row ) {
 		if ( !file_can_view_bug_attachments( $p_issue_id, (int)$t_attachment_row['user_id'] ) ) {
@@ -310,7 +310,7 @@ function mci_issue_get_notes( $p_issue_id ) {
 	$t_project_id = bug_get_field( $p_issue_id, 'project_id' );
 	$t_user_bugnote_order = 'ASC'; // always get the notes in ascending order for consistency to the calling application.
 	$t_has_time_tracking_access = access_has_bug_level( config_get( 'time_tracking_view_threshold' ), $p_issue_id );
-	
+
 	$t_result = array();
 	foreach( bugnote_get_all_visible_bugnotes( $p_issue_id, $t_user_bugnote_order, 0 ) as $t_value ) {
 		$t_bugnote = array();
@@ -323,7 +323,7 @@ function mci_issue_get_notes( $p_issue_id ) {
 		$t_bugnote['time_tracking'] = $t_has_time_tracking_access ? $t_value->time_tracking : 0;
 		$t_bugnote['note_type'] = $t_value->note_type;
 		$t_bugnote['note_attr'] = $t_value->note_attr;
-		
+
 		$t_result[] = $t_bugnote;
 	}
 
@@ -332,55 +332,58 @@ function mci_issue_get_notes( $p_issue_id ) {
 
 /**
  * Sets the monitors of the specified issue
- * 
+ *
  * <p>This functions performs access level checks and only performs operations which would
  * modify the existing monitors list.</p>
- * 
+ *
  * @param int $p_issue_id the issue id to set the monitors for
  * @param int $p_user_id the user which requests the monitor change
- * @param array $p_monitors An array of arrays with the <em>id</em> field set to the id 
+ * @param array $p_monitors An array of arrays with the <em>id</em> field set to the id
  *  of the users which should monitor this issue.
  */
 function mci_issue_set_monitors( $p_issue_id , $p_user_id, $p_monitors ) {
-    
-    $t_existing_monitors = bug_get_monitors( $p_issue_id );
+	if ( bug_is_readonly( $p_issue_id ) ) {
+		return mci_soap_fault_access_denied( $p_user_id, "Issue '$p_issue_id' is readonly" );
+	}
 
-    $t_monitors = array();
-    foreach ( $p_monitors as $t_monitor ) 
-        $t_monitors[] = $t_monitor['id'];
-    
-    foreach ( $t_monitors as $t_user_id ) {
-        
-    	if ( $p_user_id == $t_user_id ) {
-    		if ( ! access_has_bug_level( config_get( 'monitor_bug_threshold' ), $p_issue_id ) )
-    		    continue;
-	    } else {
-	    	if ( !access_has_bug_level( config_get( 'monitor_add_others_bug_threshold' ), $p_issue_id ) )
-	    	    continue;
-	    }
-	        
-       if ( in_array( $p_user_id, $t_existing_monitors) )
-           continue;
-	        
-        bug_monitor( $p_issue_id, $t_user_id);
-    }
-    
-    foreach ( $t_existing_monitors as $t_user_id ) {
+	$t_existing_monitors = bug_get_monitors( $p_issue_id );
+
+	$t_monitors = array();
+	foreach ( $p_monitors as $t_monitor )
+		$t_monitors[] = $t_monitor['id'];
+
+	foreach ( $t_monitors as $t_user_id ) {
+
+		if ( $p_user_id == $t_user_id ) {
+			if ( ! access_has_bug_level( config_get( 'monitor_bug_threshold' ), $p_issue_id ) )
+				continue;
+		} else {
+			if ( !access_has_bug_level( config_get( 'monitor_add_others_bug_threshold' ), $p_issue_id ) )
+				continue;
+		}
+
+		if ( in_array( $p_user_id, $t_existing_monitors) )
+			continue;
+
+		bug_monitor( $p_issue_id, $t_user_id);
+	}
+
+	foreach ( $t_existing_monitors as $t_user_id ) {
+
+		if ( $p_user_id == $t_user_id ) {
+			if ( ! access_has_bug_level( config_get( 'monitor_bug_threshold' ), $p_issue_id ) )
+				continue;
+		} else {
+			if ( !access_has_bug_level( config_get( 'monitor_delete_others_bug_threshold' ), $p_issue_id ) )
+				continue;
+		}
+
+		if ( in_array( $p_user_id, $t_monitors) )
+			continue;
+
+		bug_unmonitor( $p_issue_id, $t_user_id);
+	}
 
-    	if ( $p_user_id == $t_user_id ) {
-    		if ( ! access_has_bug_level( config_get( 'monitor_bug_threshold' ), $p_issue_id ) )
-    		    continue;
-	    } else {
-	    	if ( !access_has_bug_level( config_get( 'monitor_delete_others_bug_threshold' ), $p_issue_id ) )
-	    	    continue;
-	    }
-        
-        if ( in_array( $p_user_id, $t_monitors) )
-            continue;
-            
-        bug_unmonitor( $p_issue_id, $t_user_id);
-    }
-                
 }
 
 /**
@@ -476,9 +479,9 @@ function mc_issue_get_id_from_summary( $p_username, $p_password, $p_summary ) {
 	if( $t_user_id === false ) {
 		return mci_soap_fault_login_failed();
 	}
-	
+
 	$t_bug_table = db_get_table( 'mantis_bug_table' );
-	
+
 	$query = "SELECT id
 		FROM $t_bug_table
 		WHERE summary = " . db_param();
@@ -512,9 +515,9 @@ function mc_issue_get_id_from_summary( $p_username, $p_password, $p_summary ) {
  * @return integer  The id of the created issue.
  */
 function mc_issue_add( $p_username, $p_password, $p_issue ) {
-	
+
 	global $g_project_override;
-	
+
 	$t_user_id = mci_check_login( $p_username, $p_password );
 	if( $t_user_id === false ) {
 		return mci_soap_fault_login_failed();
@@ -578,7 +581,7 @@ function mc_issue_add( $p_username, $p_password, $p_issue ) {
 	}
 
 	$t_category = isset ( $p_issue['category'] ) ? $p_issue['category'] : null;
-	
+
 	$t_category_id = translate_category_name_to_id( $t_category, $t_project_id );
 	if ( $t_category_id == 0 && !config_get( 'allow_no_category' ) ) {
 		if ( !isset( $p_issue['category'] ) || is_blank( $p_issue['category'] ) ) {
@@ -634,11 +637,11 @@ function mc_issue_add( $p_username, $p_password, $p_issue ) {
 	$t_bug_data->view_state = $t_view_state_id;
 	$t_bug_data->summary = $t_summary;
 	$t_bug_data->sponsorship_total = isset( $p_issue['sponsorship_total'] ) ? $p_issue['sponsorship_total'] : 0;
-	if (  isset ( $p_issue['sticky']) && 
-	     access_has_project_level( config_get( 'set_bug_sticky_threshold', null, null, $t_project_id ), $t_project_id ) ) {
-	    $t_bug_data->sticky = $p_issue['sticky'];
+	if (  isset ( $p_issue['sticky']) &&
+		 access_has_project_level( config_get( 'set_bug_sticky_threshold', null, null, $t_project_id ), $t_project_id ) ) {
+		$t_bug_data->sticky = $p_issue['sticky'];
 	}
-	
+
 	if ( isset( $p_issue['due_date'] ) && access_has_global_level( config_get( 'due_date_update_threshold' ) ) ) {
 		$t_bug_data->due_date = mci_iso8601_to_timestamp( $p_issue['due_date'] );
 	} else {
@@ -648,7 +651,7 @@ function mc_issue_add( $p_username, $p_password, $p_issue ) {
 	if( access_has_project_level( config_get( 'roadmap_update_threshold' ), $t_bug_data->project_id, $t_user_id ) ) {
 		$t_bug_data->target_version = isset( $p_issue['target_version'] ) ? $p_issue['target_version'] : '';
 	}
-	
+
 	# omitted:
 	# var $bug_text_id
 	# $t_bug_data->profile_id;
@@ -662,7 +665,7 @@ function mc_issue_add( $p_username, $p_password, $p_issue ) {
 
 	mci_issue_set_custom_fields( $t_issue_id, $p_issue['custom_fields'], false );
 	if ( isset ( $p_issue['monitors'] ) )
-	    mci_issue_set_monitors( $t_issue_id , $t_user_id, $p_issue['monitors'] );
+		mci_issue_set_monitors( $t_issue_id , $t_user_id, $p_issue['monitors'] );
 
 	if( isset( $t_notes ) && is_array( $t_notes ) ) {
 		foreach( $t_notes as $t_note ) {
@@ -671,7 +674,7 @@ function mc_issue_add( $p_username, $p_password, $p_issue ) {
 			} else {
 				$t_view_state = config_get( 'default_bugnote_view_status' );
 			}
-			
+
 			$note_type = isset ( $t_note['note_type'] ) ? (int) $t_note['note_type'] : BUGNOTE;
 			$note_attr = isset ( $t_note['note_type'] ) ? $t_note['note_attr'] : '';
 
@@ -679,10 +682,10 @@ function mc_issue_add( $p_username, $p_password, $p_issue ) {
 			bugnote_add( $t_issue_id, $t_note['text'], mci_get_time_tracking_from_note( $t_issue_id, $t_note ), $t_view_state_id == VS_PRIVATE, $note_type, $note_attr, $t_user_id, FALSE );
 		}
 	}
-	
+
 	if ( isset ( $p_issue['tags']) && is_array ( $p_issue['tags']) ) {
 		mci_tag_set_for_issue( $t_issue_id, $p_issue['tags'], $t_user_id );
-	}	
+	}
 
 	email_new_bug( $t_issue_id );
 
@@ -700,7 +703,7 @@ function mc_issue_add( $p_username, $p_password, $p_issue ) {
  */
 function mc_issue_update( $p_username, $p_password, $p_issue_id, $p_issue ) {
 	global $g_project_override;
-	
+
 	$t_user_id = mci_check_login( $p_username, $p_password );
 	if( $t_user_id === false ) {
 		return mci_soap_fault_login_failed();
@@ -710,12 +713,16 @@ function mc_issue_update( $p_username, $p_password, $p_issue_id, $p_issue ) {
 		return new soap_fault( 'Client', '', "Issue '$p_issue_id' does not exist." );
 	}
 
+	if( bug_is_readonly( $p_issue_id ) ) {
+		return mci_soap_fault_access_denied( $t_user_id, "Issue '$p_issue_id' is readonly" );
+	}
+
 	$t_project_id = bug_get_field( $p_issue_id, 'project_id' );
 
 	if( !mci_has_readwrite_access( $t_user_id, $t_project_id ) ) {
 		return mci_soap_fault_access_denied( $t_user_id );
 	}
-	
+
 	$g_project_override = $t_project_id; // ensure that helper_get_current_project() calls resolve to this project id
 
 	$t_project_id = mci_get_project_id( $p_issue['project'] );
@@ -724,8 +731,8 @@ function mc_issue_update( $p_username, $p_password, $p_issue_id, $p_issue ) {
 	$t_project = $p_issue['project'];
 	$t_summary = isset( $p_issue['summary'] ) ? $p_issue['summary'] : '';
 	$t_description = isset( $p_issue['description'] ) ? $p_issue['description'] : '';
-	
-	
+
+
 	if(( $t_project_id == 0 ) || !project_exists( $t_project_id ) ) {
 		if( $t_project_id == 0 ) {
 			return new soap_fault( 'Client', '', "Project '" . $t_project['name'] . "' does not exist." );
@@ -742,12 +749,13 @@ function mc_issue_update( $p_username, $p_password, $p_issue_id, $p_issue ) {
 	}
 
 	$t_category = isset ( $p_issue['category'] ) ? $p_issue['category'] : null;
-	
+
 	$t_category_id = translate_category_name_to_id( $t_category, $t_project_id );
 	if ( $t_category_id == 0 && !config_get( 'allow_no_category' ) ) {
 		if ( isset( $p_issue['category'] ) && !is_blank( $p_issue['category'] ) ) {
 			return new soap_fault( 'Client', '', "Category field must be supplied." );
 		} else {
+			$t_project_name = project_get_name( $t_project_id );
 			return new soap_fault( 'Client', '', "Category '" . $p_issue['category'] . "' not found for project '$t_project_name'." );
 		}
 	}
@@ -820,7 +828,7 @@ function mc_issue_update( $p_username, $p_password, $p_issue_id, $p_issue ) {
 	if ( isset ( $p_issue['fixed_in_version'] ) )
 		$t_bug_data->fixed_in_version = $p_issue['fixed_in_version'];
 	if (  isset ( $p_issue['sticky']) && access_has_bug_level( config_get( 'set_bug_sticky_threshold' ), $t_bug_data->id ) ) {
-	    $t_bug_data->sticky = $p_issue['sticky'];
+		$t_bug_data->sticky = $p_issue['sticky'];
 	}
 
 	if ( isset( $p_issue['due_date'] ) && access_has_global_level( config_get( 'due_date_update_threshold' ) ) ) {
@@ -835,7 +843,7 @@ function mc_issue_update( $p_username, $p_password, $p_issue_id, $p_issue ) {
 
 	mci_issue_set_custom_fields( $p_issue_id, $p_issue['custom_fields'], true );
 	if ( isset ( $p_issue['monitors'] ) )
-	    mci_issue_set_monitors( $p_issue_id , $t_user_id, $p_issue['monitors'] );
+		mci_issue_set_monitors( $p_issue_id , $t_user_id, $p_issue['monitors'] );
 
 	if ( isset( $p_issue['notes'] ) && is_array( $p_issue['notes'] ) ) {
 
@@ -883,42 +891,46 @@ function mc_issue_update( $p_username, $p_password, $p_issue_id, $p_issue ) {
 				}
 			} else {
 				$t_view_state_id = mci_get_enum_id_from_objectref( 'view_state', $t_view_state );
-				
+
 				$note_type = isset ( $t_note['note_type'] ) ? (int) $t_note['note_type'] : BUGNOTE;
-			    $note_attr = isset ( $t_note['note_type'] ) ? $t_note['note_attr'] : '';
-				
+				$note_attr = isset ( $t_note['note_type'] ) ? $t_note['note_attr'] : '';
+
 				bugnote_add( $p_issue_id, $t_note['text'], mci_get_time_tracking_from_note( $p_issue_id, $t_note ), $t_view_state_id == VS_PRIVATE, $note_type, $note_attr, $t_user_id, FALSE );
 			}
 		}
 	}
-	
+
 	if ( isset ( $p_issue['tags']) && is_array ( $p_issue['tags']) ) {
 		mci_tag_set_for_issue( $p_issue_id, $p_issue['tags'] , $t_user_id );
 	}
-	
+
 	# submit the issue
 	return $t_is_success = $t_bug_data->update( /* update_extended */ true, /* bypass_email */ false);
 }
 
 function mc_issue_set_tags ( $p_username, $p_password, $p_issue_id, $p_tags ) {
-	
+
 	$t_user_id = mci_check_login( $p_username, $p_password );
 	if( $t_user_id === false ) {
 		return mci_soap_fault_login_failed();
 	}
-	
+
 	if( !bug_exists( $p_issue_id ) ) {
 		return new soap_fault( 'Client', '', "Issue '$p_issue_id' does not exist." );
 	}
-	
+
 	$t_project_id = bug_get_field( $p_issue_id, 'project_id' );
-	
+
 	if( !mci_has_readwrite_access( $t_user_id, $t_project_id ) ) {
 		return mci_soap_fault_access_denied( $t_user_id );
 	}
-	
+
+	if( bug_is_readonly( $p_issue_id ) ) {
+		return mci_soap_fault_access_denied( $t_user_id, "Issue '$p_issue_id' is readonly" );
+	}
+
 	mci_tag_set_for_issue( $p_issue_id,  $p_tags, $t_user_id );
-	
+
 	return true;
 }
 
@@ -944,9 +956,9 @@ function mc_issue_delete( $p_username, $p_password, $p_issue_id ) {
 	if( !mci_has_readwrite_access( $t_user_id, $t_project_id ) ) {
 		return mci_soap_fault_access_denied( $t_user_id );
 	}
-	
+
 	if ( !access_has_bug_level( config_get( 'delete_bug_threshold' ), $p_issue_id, $t_user_id ) ) {
-	    return mci_soap_fault_access_denied( $t_user_id );
+		return mci_soap_fault_access_denied( $t_user_id );
 	}
 
 	return bug_delete( $p_issue_id );
@@ -999,9 +1011,9 @@ function mc_issue_note_add( $p_username, $p_password, $p_issue_id, $p_note ) {
 			'id' => config_get( 'default_bug_view_status' ),
 		);
 	}
-	
+
 	$t_view_state_id = mci_get_enum_id_from_objectref( 'view_state', $t_view_state );
-	
+
 	$note_type = isset ( $p_note['note_type'] ) ? (int) $p_note['note_type'] : BUGNOTE;
 	$note_attr = isset ( $p_note['note_type'] ) ? $p_note['note_attr'] : '';
 
@@ -1035,14 +1047,18 @@ function mc_issue_note_delete( $p_username, $p_password, $p_issue_note_id ) {
 	if( !mci_has_readwrite_access( $t_user_id, $t_project_id ) ) {
 		return mci_soap_fault_access_denied( $t_user_id );
 	}
-	
-	$t_reporter_id = bugnote_get_field( $p_issue_note_id, 'reporter_id' );	
-	
+
+	$t_reporter_id = bugnote_get_field( $p_issue_note_id, 'reporter_id' );
+
 	// mirrors check from bugnote_delete.php
 	if ( ( $t_user_id != $t_reporter_id ) || ( OFF == config_get( 'bugnote_allow_user_edit_delete' ) ) ) {
-	    if ( !access_has_bugnote_level( config_get( 'delete_bugnote_threshold' ), $p_issue_note_id ) ) {
-	        return mci_soap_fault_access_denied( $t_user_id );
-	    }
+		if ( !access_has_bugnote_level( config_get( 'delete_bugnote_threshold' ), $p_issue_note_id ) ) {
+			return mci_soap_fault_access_denied( $t_user_id );
+		}
+	}
+
+	if( bug_is_readonly( $t_issue_id ) ) {
+		return mci_soap_fault_access_denied( $t_user_id, "Issue '$t_issue_id' is readonly" );
 	}
 
 	return bugnote_delete( $p_issue_note_id );
@@ -1057,51 +1073,64 @@ function mc_issue_note_delete( $p_username, $p_password, $p_issue_note_id ) {
  * @return true on success, false on failure
  */
 function mc_issue_note_update( $p_username, $p_password, $p_note ) {
-    $t_user_id = mci_check_login( $p_username, $p_password );
-    
-    if( $t_user_id === false ) {
-        return mci_soap_fault_login_failed();
-    }
+	$t_user_id = mci_check_login( $p_username, $p_password );
 
-    if ( !isset( $p_note['id'] ) || is_blank( $p_note['id'] ) ) {
-        return new soap_fault( 'Client', '', "Issue id must not be blank." );
-    }
-    
-    if ( !isset( $p_note['text'] ) || is_blank( $p_note['text'] ) ) {
-        return new soap_fault( 'Client', '', "Issue note text must not be blank." );
-    }
-    
-    $t_issue_note_id = $p_note['id'];
+	if ( $t_user_id === false ) {
+		return mci_soap_fault_login_failed();
+	}
+
+	if ( !isset( $p_note['id'] ) || is_blank( $p_note['id'] ) ) {
+		return new soap_fault( 'Client', '', "Issue note id must not be blank." );
+	}
+
+	if ( !isset( $p_note['text'] ) || is_blank( $p_note['text'] ) ) {
+		return new soap_fault( 'Client', '', "Issue note text must not be blank." );
+	}
+
+	$t_issue_note_id = $p_note['id'];
+
+	if ( !bugnote_exists( $t_issue_note_id ) ) {
+		return new soap_fault( 'Server', '', "Issue note '$t_issue_note_id' does not exist." );
+	}
 
-    if( !bugnote_exists( $t_issue_note_id ) ) {
-        return new soap_fault( 'Server', '', "Issue note '$t_issue_note_id' does not exist." );
-    }
-    
 	$t_issue_id = bugnote_get_field( $t_issue_note_id, 'bug_id' );
-	
 	$t_project_id = bug_get_field( $t_issue_id, 'project_id' );
 
-    if( !mci_has_readwrite_access( $t_user_id, $t_project_id ) ) {
-        return mci_soap_fault_access_denied( $t_user_id );
-    }
+	if ( !mci_has_readwrite_access( $t_user_id, $t_project_id ) ) {
+		return mci_soap_fault_access_denied( $t_user_id );
+	}
 
-    if( !access_has_bug_level( config_get( 'add_bugnote_threshold' ), $t_issue_id, $t_user_id ) ) {
-        return mci_soap_fault_access_denied( $t_user_id, "You do not have access rights to add notes to this issue" );
-    }
+	$t_issue_author_id = bugnote_get_field( $t_issue_note_id, 'reporter_id' );
 
-    if( bug_is_readonly( $t_issue_id ) ) {
-        return mci_soap_fault_access_denied( $t_user_id, "Issue ' . $t_issue_id . ' is readonly" );
-    }
+	# Check if the user owns the bugnote and is allowed to update their own bugnotes
+	# regardless of the update_bugnote_threshold level.
+	$t_user_owns_the_bugnote = bugnote_is_user_reporter( $t_issue_note_id, $t_user_id );
+	$t_user_can_update_own_bugnote = config_get( 'bugnote_allow_user_edit_delete', null, $t_user_id, $t_project_id );
+	if ( $t_user_owns_the_bugnote && !$t_user_can_update_own_bugnote ) {
+		return mci_soap_fault_access_denied( $t_user_id );
+	}
 
-    if( isset( $p_note['view_state'] )) {
-        $t_view_state = $p_note['view_state'];
-        $t_view_state_id = mci_get_enum_id_from_objectref( 'view_state', $t_view_state );
-        bugnote_set_view_state( $t_issue_note_id, $t_view_state_id );
-    }
+	# Check if the user has an access level beyond update_bugnote_threshold for the
+	# project containing the bugnote to update.
+	$t_update_bugnote_threshold = config_get( 'update_bugnote_threshold', null, $t_user_id, $t_project_id );
+	if ( !$t_user_owns_the_bugnote && !access_has_bugnote_level( $t_update_bugnote_threshold, $t_issue_note_id, $t_user_id ) ) {
+		return mci_soap_fault_access_denied( $t_user_id );
+	}
 
-    bugnote_set_text( $t_issue_note_id, $p_note['text'] );
+	# Check if the bug is readonly
+	if ( bug_is_readonly( $t_issue_id ) ) {
+		return mci_soap_fault_access_denied( $t_user_id, "Issue ' . $t_issue_id . ' is readonly" );
+	}
 
-    return bugnote_date_update( $t_issue_note_id );
+	if ( isset( $p_note['view_state'] ) ) {
+		$t_view_state = $p_note['view_state'];
+		$t_view_state_id = mci_get_enum_id_from_objectref( 'view_state', $t_view_state );
+		bugnote_set_view_state( $t_issue_note_id, $t_view_state_id );
+	}
+
+	bugnote_set_text( $t_issue_note_id, $p_note['text'] );
+
+	return bugnote_date_update( $t_issue_note_id );
 }
 
 /**
@@ -1285,33 +1314,33 @@ function mc_issue_checkin( $p_username, $p_password, $p_issue_id, $p_comment, $p
 
 /**
  * Returns the date in iso8601 format, with proper timezone offset applied
- * 
+ *
  * @param string $p_date the date in iso8601 format
  * @return int the timestamp
  */
 function mci_iso8601_to_timestamp( $p_date ) {
-	
+
 	// retrieve the offset, seems to be lost by nusoap
 	$t_utc_date = new DateTime( $p_date, new DateTimeZone( 'UTC' ) );
 	$t_timezone = new DateTimeZone( date_default_timezone_get() );
-	$t_offset = $t_timezone->getOffset( $t_utc_date ); 
-	
+	$t_offset = $t_timezone->getOffset( $t_utc_date );
+
 	$t_raw_timestamp = iso8601_to_timestamp( $p_date );
-	
+
 	return $t_raw_timestamp - $t_offset;
-	
+
 }
 
 /**
  * Returns an array for SOAP encoding from a BugData object
- * 
+ *
  * @param BugData $p_issue_data
  * @param int $p_user_id
  * @param string $p_lang
  * @return array The issue as an array
  */
 function mci_issue_data_as_array( $p_issue_data, $p_user_id, $p_lang ) {
-	
+
 		$t_id = $p_issue_data->id;
 
 		$t_issue = array();
@@ -1336,7 +1365,7 @@ function mci_issue_data_as_array( $p_issue_data, $p_user_id, $p_lang ) {
 		$t_issue['reproducibility'] = mci_enum_get_array_by_id( $p_issue_data->reproducibility, 'reproducibility', $p_lang );
 		$t_issue['date_submitted'] = timestamp_to_iso8601( $p_issue_data->date_submitted, false );
 		$t_issue['sticky'] = $p_issue_data->sticky;
-		
+
 		$t_issue['sponsorship_total'] = $p_issue_data->sponsorship_total;
 
 		if( !empty( $p_issue_data->handler_id ) ) {
@@ -1362,31 +1391,31 @@ function mci_issue_data_as_array( $p_issue_data, $p_user_id, $p_lang ) {
 		$t_issue['notes'] = mci_issue_get_notes( $p_issue_data->id );
 		$t_issue['custom_fields'] = mci_issue_get_custom_fields( $p_issue_data->id );
 		$t_issue['tags'] = mci_issue_get_tags_for_bug_id( $p_issue_data->id, $p_user_id );
-		
+
 		return $t_issue;
 }
 
 function mci_issue_get_tags_for_bug_id( $p_bug_id, $p_user_id ) {
-	
+
 	if ( !access_has_global_level( config_get( 'tag_view_threshold' ), $p_user_id ) )
 		return array();
-	
+
 	$t_tag_rows = tag_bug_get_attached( $p_bug_id );
 	$t_result = array();
-	
+
 	foreach ( $t_tag_rows as $t_tag_row ) {
 		$t_result[] = array (
 			'id' => $t_tag_row['id'],
 			'name' => $t_tag_row['name']
 		);
 	}
-	
+
 	return $t_result;
 }
 
 /**
  * Returns an array for SOAP encoding from a BugData object
- * 
+ *
  * @param BugData $p_issue_data
  * @return array The issue header data as an array
  */
@@ -1395,7 +1424,7 @@ function mci_issue_data_as_header_array( $p_issue_data ) {
 		$t_issue = array();
 
 		$t_id = $p_issue_data->id;
-		
+
 		$t_issue['id'] = $t_id;
 		$t_issue['view_state'] = $p_issue_data->view_state;
 		$t_issue['last_updated'] = timestamp_to_iso8601( $p_issue_data->last_updated, false );
