@@ -22,7 +22,7 @@
  * @package CoreAPI
  * @subpackage CSVAPI
  * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
- * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+ * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
  * @link http://www.mantisbt.org
  */
 
@@ -97,312 +97,312 @@ function csv_get_columns() {
 }
 
 /**
- * format bug id
- * @param int $p_bug_id bug id
- * @return string csv formatted bug
+ * returns the formatted bug id
+ * @param object $p_bug the bug
+ * @return string csv formatted bug id
  * @access public
  */
-function csv_format_id( $p_bug_id ) {
-	return bug_format_id( $p_bug_id );
+function csv_format_id( $p_bug ) {
+	return bug_format_id( $p_bug->id );
 }
 
 /**
- * returns the project name corresponding to the supplied project id.
- * @param int $p_project_id project id
+ * returns the project name corresponding to the supplied bug
+ * @param object $p_bug the bug
  * @return string csv formatted project name
  * @access public
  */
-function csv_format_project_id( $p_project_id ) {
-	return csv_escape_string( project_get_name( $p_project_id ) );
+function csv_format_project_id( $p_bug ) {
+	return csv_escape_string( project_get_name( $p_bug->project_id ) );
 }
 
 /**
- * returns the reporter name corresponding to the supplied id.
- * @param int $p_reporter_id user id
+ * returns the reporter name corresponding to the supplied bug
+ * @param object $p_bug the bug
  * @return string formatted user name
  * @access public
  */
-function csv_format_reporter_id( $p_reporter_id ) {
-	return csv_escape_string( user_get_name( $p_reporter_id ) );
+function csv_format_reporter_id( $p_bug ) {
+	return csv_escape_string( user_get_name( $p_bug->reporter_id ) );
 }
 
 /**
- * returns the handler name corresponding to the supplied id
- * @param int $p_handler_id user id
+ * returns the handler name corresponding to the supplied bug
+ * @param object $p_bug the bug
  * @return string formatted user name
  * @access public
  */
-function csv_format_handler_id( $p_handler_id ) {
-	if( $p_handler_id > 0 ) {
-		return csv_escape_string( user_get_name( $p_handler_id ) );
+function csv_format_handler_id( $p_bug ) {
+	if( $p_bug->handler_id > 0 ) {
+		return csv_escape_string( user_get_name( $p_bug->handler_id ) );
 	}
 }
 
 /**
  * return the priority string
- * @param int $p_priority
+ * @param object $p_bug the bug
  * @return string formatted priority string
  * @access public
  */
-function csv_format_priority( $p_priority ) {
-	return csv_escape_string( get_enum_element( 'priority', $p_priority ) );
+function csv_format_priority( $p_bug ) {
+	return csv_escape_string( get_enum_element( 'priority', $p_bug->priority, auth_get_current_user_id(), $p_bug->project_id ) );
 }
 
 /**
  * return the severity string
- * @param int $p_severity
+ * @param object $p_bug the bug
  * @return string formatted severity string
  * @access public
  */
-function csv_format_severity( $p_severity ) {
-	return csv_escape_string( get_enum_element( 'severity', $p_severity ) );
+function csv_format_severity( $p_bug ) {
+	return csv_escape_string( get_enum_element( 'severity', $p_bug->severity, auth_get_current_user_id(), $p_bug->project_id ) );
 }
 
 /**
- * return the reproducability string
- * @param int $p_reproducibility
+ * return the reproducibility string
+ * @param object $p_bug the bug
  * @return string formatted reproducibility string
  * @access public
  */
-function csv_format_reproducibility( $p_reproducibility ) {
-	return csv_escape_string( get_enum_element( 'reproducibility', $p_reproducibility ) );
+function csv_format_reproducibility( $p_bug ) {
+	return csv_escape_string( get_enum_element( 'reproducibility', $p_bug->reproducibility, auth_get_current_user_id(), $p_bug->project_id ) );
 }
 
 /**
  * return the version
- * @param string $p_version version string
+ * @param object $p_bug the bug
  * @return string formatted version string
  * @access public
  */
-function csv_format_version( $p_version ) {
-	return csv_escape_string( $p_version );
+function csv_format_version( $p_bug ) {
+	return csv_escape_string( $p_bug->version );
 }
 
 /**
  * return the fixed_in_version
- * @param string $p_fixed_in_version fixed in version string
+ * @param object $p_bug the bug
  * @return string formatted fixed in version string
  * @access public
  */
-function csv_format_fixed_in_version( $p_fixed_in_version ) {
-	return csv_escape_string( $p_fixed_in_version );
+function csv_format_fixed_in_version( $p_bug ) {
+	return csv_escape_string( $p_bug->fixed_in_version );
 }
 
 /**
  * return the target_version
- * @param string $p_target_version target version string
+ * @param object $p_bug the bug
  * @return string formatted target version string
  * @access public
  */
-function csv_format_target_version( $p_target_version ) {
-	return csv_escape_string( $p_target_version );
+function csv_format_target_version( $p_bug ) {
+	return csv_escape_string( $p_bug->target_version );
 }
 
 /**
  * return the projection
- * @param int $p_projection
+ * @param object $p_bug the bug
  * @return string formatted projection string
  * @access public
  */
-function csv_format_projection( $p_projection ) {
-	return csv_escape_string( get_enum_element( 'projection', $p_projection ) );
+function csv_format_projection( $p_bug ) {
+	return csv_escape_string( get_enum_element( 'projection', $p_bug->projection, auth_get_current_user_id(), $p_bug->project_id ) );
 }
 
 /**
  * return the category
- * @param int $p_category_id
+ * @param object $p_bug the bug
  * @return string formatted category string
  * @access public
  */
-function csv_format_category_id( $p_category_id ) {
-	return csv_escape_string( category_full_name( $p_category_id, false ) );
+function csv_format_category_id( $p_bug ) {
+	return csv_escape_string( category_full_name( $p_bug->category_id, false ) );
 }
 
 /**
  * return the date submitted
- * @param string $p_date_submitted
+ * @param object $p_bug the bug
  * @return string formatted date
  * @access public
  */
-function csv_format_date_submitted( $p_date_submitted ) {
+function csv_format_date_submitted( $p_bug ) {
 	static $s_date_format = null;
 	if ( $s_date_format === null )
 		$s_date_format = config_get( 'short_date_format' );
-	return date( $s_date_format, $p_date_submitted );
+	return date( $s_date_format, $p_bug->date_submitted );
 }
 
 /**
  * return the eta
- * @param int $p_eta eta
+ * @param object $p_bug the bug
  * @return string formatted eta
  * @access public
  */
-function csv_format_eta( $p_eta ) {
-	return csv_escape_string( get_enum_element( 'eta', $p_eta ) );
+function csv_format_eta( $p_bug ) {
+	return csv_escape_string( get_enum_element( 'eta', $p_bug->eta, auth_get_current_user_id(), $p_bug->project_id ) );
 }
 
 /**
  * return the operating system
- * @param string $p_os operating system
+ * @param object $p_bug the bug
  * @return string formatted operating system
  * @access public
  */
-function csv_format_os( $p_os ) {
-	return csv_escape_string( $p_os );
+function csv_format_os( $p_bug ) {
+	return csv_escape_string( $p_bug->os );
 }
 
 /**
  * return the os build (os version)
- * @param string $p_os_build operating system build
+ * @param object $p_bug the bug
  * @return string formatted operating system build
  * @access public
  */
-function csv_format_os_build( $p_os_build ) {
-	return csv_escape_string( $p_os_build );
+function csv_format_os_build( $p_bug ) {
+	return csv_escape_string( $p_bug->os_build );
 }
 
 /**
  * return the build
- * @param string $p_build
+ * @param object $p_bug the bug
  * @return string formatted build
  * @access public
  */
-function csv_format_build( $p_build ) {
-	return csv_escape_string( $p_build );
+function csv_format_build( $p_bug ) {
+	return csv_escape_string( $p_bug->build );
 }
 
 /**
  * return the platform
- * @param string $p_platform platform
+ * @param object $p_bug the bug
  * @return string formatted platform
  * @access public
  */
-function csv_format_platform( $p_platform ) {
-	return csv_escape_string( $p_platform );
+function csv_format_platform( $p_bug ) {
+	return csv_escape_string( $p_bug->platform );
 }
 
 /**
  * return the view state (eg: private / public)
- * @param int $p_view_state view state
+ * @param object $p_bug the bug
  * @return string formatted view state
  * @access public
  */
-function csv_format_view_state( $p_view_state ) {
-	return csv_escape_string( get_enum_element( 'view_state', $p_view_state ) );
+function csv_format_view_state( $p_bug ) {
+	return csv_escape_string( get_enum_element( 'view_state', $p_bug->view_state, auth_get_current_user_id(), $p_bug->project_id ) );
 }
 
 /**
  * return the last updated date
- * @param string $p_last_updated last updated
+ * @param object $p_bug the bug
  * @return string formated last updated string
  * @access public
  */
-function csv_format_last_updated( $p_last_updated ) {
+function csv_format_last_updated( $p_bug ) {
 	static $s_date_format = null;
 	if ( $s_date_format === null )
 		$s_date_format = config_get( 'short_date_format' );
-	return date( $s_date_format, $p_last_updated );
+	return date( $s_date_format, $p_bug->last_updated );
 }
 
 /**
  * return the summary
- * @param string $p_summary summary
+ * @param object $p_bug the bug
  * @return string formatted summary
  * @access public
  */
-function csv_format_summary( $p_summary ) {
-	return csv_escape_string( $p_summary );
+function csv_format_summary( $p_bug ) {
+	return csv_escape_string( $p_bug->summary );
 }
 
 /**
  * return the description
- * @param string $p_description description
+ * @param object $p_bug the bug
  * @return string formatted description
  * @access public
  */
-function csv_format_description( $p_description ) {
-	return csv_escape_string( $p_description );
+function csv_format_description( $p_bug ) {
+	return csv_escape_string( $p_bug->description );
 }
 
 /**
  * return the steps to reproduce
- * @param string $p_steps_to_reproduce steps to reproduce
+ * @param object $p_bug the bug
  * @return string formatted steps to reproduce
  * @access public
  */
-function csv_format_steps_to_reproduce( $p_steps_to_reproduce ) {
-	return csv_escape_string( $p_steps_to_reproduce );
+function csv_format_steps_to_reproduce( $p_bug ) {
+	return csv_escape_string( $p_bug->steps_to_reproduce );
 }
 
 /**
  * return the additional information
- * @param string $p_additional_information
+ * @param object $p_bug the bug
  * @return string formatted additional information
  * @access public
  */
-function csv_format_additional_information( $p_additional_information ) {
-	return csv_escape_string( $p_additional_information );
+function csv_format_additional_information( $p_bug ) {
+	return csv_escape_string( $p_bug->additional_information );
 }
 
 /**
  * return the status string
- * @param string $p_status status
+ * @param object $p_bug the bug
  * @return string formatted status
  * @access public
  */
-function csv_format_status( $p_status ) {
-	return csv_escape_string( get_enum_element( 'status', $p_status ) );
+function csv_format_status( $p_bug ) {
+	return csv_escape_string( get_enum_element( 'status', $p_bug->status, auth_get_current_user_id(), $p_bug->project_id ) );
 }
 
 /**
  * return the resolution string
- * @param int $p_resolution resolution
+ * @param object $p_bug the bug
  * @return string formatted resolution string
  * @access public
  */
-function csv_format_resolution( $p_resolution ) {
-	return csv_escape_string( get_enum_element( 'resolution', $p_resolution ) );
+function csv_format_resolution( $p_bug ) {
+	return csv_escape_string( get_enum_element( 'resolution', $p_bug->resolution, auth_get_current_user_id(), $p_bug->project_id ) );
 }
 
 /**
  * return the duplicate bug id
- * @param int $p_duplicate_id
+ * @param object $p_bug the bug
  * @return string formatted bug id
  * @access public
  */
-function csv_format_duplicate_id( $p_duplicate_id ) {
-	return bug_format_id( $p_duplicate_id );
+function csv_format_duplicate_id( $p_bug ) {
+	return bug_format_id( $p_bug->duplicate_id );
 }
 
 /**
  * return the selection
- * @param int $p_duplicate_id
+ * @param object $p_bug the bug
  * @return string
  * @access public
  */
-function csv_format_selection( $p_duplicate_id ) {
+function csv_format_selection( $p_bug ) {
 	return csv_escape_string( '' );
 }
 
 /**
  * return the due date column
- * @param int $p_due_date
+ * @param object $p_bug the bug
  * @return string
  * @access public
  */
-function csv_format_due_date( $p_due_date ) {
+function csv_format_due_date( $p_bug ) {
 	static $s_date_format = null;
 	if ( $s_date_format === null )
 		$s_date_format = config_get( 'short_date_format' );
-	return csv_escape_string( date( $s_date_format, $p_due_date ) );
+	return csv_escape_string( date( $s_date_format, $p_bug->due_date ) );
 }
 
 /**
  * return the sponsorship total for an issue
- * @param int $p_sponsorship_total
+ * @param object $p_bug the bug
  * @return string
  * @access public
  */
-function csv_format_sponsorship_total( $p_sponsorship_total ) {
-	return number_format( $p_sponsorship_total );
+function csv_format_sponsorship_total( $p_bug ) {
+	return csv_escape_string( $p_bug->sponsorship_total );
 }
